@@ -1,7 +1,7 @@
 package File::Digest;
 
 our $DATE = '2016-11-21'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,7 +28,7 @@ $SPEC{digest_files} = {
         files => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'file',
-            schema => ['array*', of=>'file*'],
+            schema => ['array*', of=>'filename*'],
             req => 1,
             pos => 0,
             greedy => 1,
@@ -120,7 +120,7 @@ File::Digest - Calculate and check file checksum/digest (using various algorithm
 
 =head1 VERSION
 
-This document describes version 0.001 of File::Digest (from Perl distribution File-Digest), released on 2016-11-21.
+This document describes version 0.002 of File::Digest (from Perl distribution File-Digest), released on 2016-11-21.
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<algorithm> => I<str> (default: "md5")
 
-=item * B<files>* => I<array[file]>
+=item * B<files>* => I<array[filename]>
 
 =back
 
